@@ -5,11 +5,11 @@ import os
 import numpy as np
 import pandas as pd
 import yaml
+from dotenv import load_dotenv
+from dwhutils.utils import divide_chunks
 from sqlalchemy import MetaData
 from termcolor2 import colored
 
-from dwhutils.utils import divide_chunks, tech_fields
-
 
 def element_is_in(comparelist, element):
     if element in comparelist:
@@ -35,6 +35,7 @@ class LoadtoDB():
         :param entityName: what entity is it? used for config read
         :param useSingeFetch: should all old data fetched in one ore in single rows? (used for update)
         '''
+        load_dotenv()
         self.data = data
         self.db_con = db_con
         self.t_name = t_name
@@ -44,17 +45,17 @@ class LoadtoDB():
         self.target_table = None
         self.entityName = entityName
         self.useSingeFetch = useSingeFetch
+
+        config_file = os.getenv('DB_CONFIG')
+        kp_path = os.getenv('KEYPASS')
+        conf_r = os.getenv('ENTITY_CONFIGS')
         if date == None:
             self.processing_date_start = datetime.date.today().strftime("%Y-%m-%d")
         else:
             self.processing_date_start = date
 
-        if os.path.isdir(r'/Configs/ENB/'):
-            conf_r = r'/Configs/ENB/'
-        else:
-            conf_r = r'../Configs/ENB/'
-        print("DbLoader")
-        if entityName == None:
+
+        if entityName is None:
             with open(conf_r + t_name + '.yaml') as file:
                 self.documents = yaml.full_load(file)
             self.hk = self.documents[t_name]['hash_key']
@@ -77,13 +78,12 @@ class LoadtoDB():
 
         try:
             stmt = "select {0} from {1}.{2} where load_domain='{3}'".format(self.hk, self.schema, self.t_name,
-                                                                        self.load_domain)
+                                                                            self.load_domain)
             table_hk = list(db_con.execute(stmt).fetchall())
         except:
             stmt = "select {0} from {1}.{2}".format(self.hk, self.schema, self.t_name)
             table_hk = list(db_con.execute(stmt).fetchall())
 
-
         table_hk = [i[0] for i in table_hk]
         df_hk = list(self.data[self.hk])
 
@@ -176,8 +176,8 @@ class LoadtoDB():
         fields_types.append('str')
 
         stmt_diffs = "select  " + ','.join(
-            fields_with_hk) + " from " + self.schema + "." + self.target_table.name + " where " + self.hk + " in " + table_u_hk + \
-                     " and processing_date_end='2262-04-11';"
+            fields_with_hk) + " from " + self.schema + "." + self.target_table.name + " where " + self.hk + " in " + \
+                     table_u_hk + " and processing_date_end='2262-04-11';"
         result = conn.execute(stmt_diffs)
         _df_list = []
 
@@ -209,7 +209,6 @@ class LoadtoDB():
         return old_data
 
     def update_v2(self):
-        print("Update")
         fields = list(self.fields)
         if len(self.update_df[self.hk]) > 0:
             conn = self.db_con.connect()
@@ -250,7 +249,9 @@ class LoadtoDB():
                         set_part.append(self.target_table.name + "." + col + "=" + "'" + str(record[col]) + "'")
                     set_part = ",\n".join(set_part)
 
-                    stmt3 = "UPDATE " + self.schema + "." + self.target_table.name + " FOR PORTION OF business_time FROM '" + self.processing_date_start + "' TO '2262-04-11' SET " + set_part + ", mod_flg = 'U'  WHERE " + self.hk + " = '" + u_hk + "';"
+                    stmt3 = "UPDATE " + self.schema + "." + self.target_table.name + " FOR PORTION OF business_time FROM '"\
+                            + self.processing_date_start + "' TO '2262-04-11' SET " + set_part + ", mod_flg = 'U'  WHERE " \
+                            + self.hk + " = '" + u_hk + "';"
                     chunk_stmt.append(stmt3)
                 st = ';'.join(chunk_stmt) + ";"
                 conn.execute(st)
